==> beast-privilege-api-3.0.2-GS-20250806.040316-16-sources.jar: com/thebeastshop/privilege/vo/PersonalCenterConfigVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class PersonalCenterConfigVO implements Serializable {
    private Integer id;
    private Integer status;
    private String statusDesc;
    private String channel;

    private String channelName;
    private String operatorNote;
    private Date createTime;
    private Date updateTime;
    private Date publishTime;
    private Integer updateId;
    private String updateMan;
    private String tabsTop;
    private String tabsBottom;
    private String tabsBottomNoShare;
    private String brands;

    private String tabsTopAndroid;
    private String tabsBottomNoShareAndroid;
    private String brandsAndroid;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getOperatorNote() {
        return operatorNote;
    }

    public void setOperatorNote(String operatorNote) {
        this.operatorNote = operatorNote;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public Integer getUpdateId() {
        return updateId;
    }

    public void setUpdateId(Integer updateId) {
        this.updateId = updateId;
    }

    public String getUpdateMan() {
        return updateMan;
    }

    public void setUpdateMan(String updateMan) {
        this.updateMan = updateMan;
    }


    public String getTabsTop() {
        return tabsTop;
    }

    public void setTabsTop(String tabsTop) {
        this.tabsTop = tabsTop;
    }

    public String getTabsBottom() {
        return tabsBottom;
    }

    public void setTabsBottom(String tabsBottom) {
        this.tabsBottom = tabsBottom;
    }


    public String getTabsBottomNoShare() {
        return tabsBottomNoShare;
    }

    public void setTabsBottomNoShare(String tabsBottomNoShare) {
        this.tabsBottomNoShare = tabsBottomNoShare;
    }

    public String getBrands() {
        return brands;
    }

    public void setBrands(String brands) {
        this.brands = brands;
    }


    public String getTabsTopAndroid() {
        return tabsTopAndroid;
    }

    public void setTabsTopAndroid(String tabsTopAndroid) {
        this.tabsTopAndroid = tabsTopAndroid;
    }

    public String getTabsBottomNoShareAndroid() {
        return tabsBottomNoShareAndroid;
    }

    public void setTabsBottomNoShareAndroid(String tabsBottomNoShareAndroid) {
        this.tabsBottomNoShareAndroid = tabsBottomNoShareAndroid;
    }

    public String getBrandsAndroid() {
        return brandsAndroid;
    }

    public void setBrandsAndroid(String brandsAndroid) {
        this.brandsAndroid = brandsAndroid;
    }
}

==> beast-privilege-api-3.0.11-GS-20250905.063335-14-sources.jar: com/thebeastshop/privilege/vo/PersonalCenterConfigVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class PersonalCenterConfigVO implements Serializable {
    private Integer id;
    private Integer status;
    private String statusDesc;
    private String channel;

    private String channelName;
    private String operatorNote;
    private Date createTime;
    private Date updateTime;
    private Date publishTime;
    private Integer updateId;
    private String updateMan;
    private String tabsTop;
    private String tabsBottom;
    private String tabsBottomNoShare;
    private String brands;

    private String tabsTopAndroid;
    private String tabsBottomNoShareAndroid;
    private String brandsAndroid;



    private String headerImage;



    private String tabsBanner;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getOperatorNote() {
        return operatorNote;
    }

    public void setOperatorNote(String operatorNote) {
        this.operatorNote = operatorNote;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public Integer getUpdateId() {
        return updateId;
    }

    public void setUpdateId(Integer updateId) {
        this.updateId = updateId;
    }

    public String getUpdateMan() {
        return updateMan;
    }

    public void setUpdateMan(String updateMan) {
        this.updateMan = updateMan;
    }


    public String getTabsTop() {
        return tabsTop;
    }

    public void setTabsTop(String tabsTop) {
        this.tabsTop = tabsTop;
    }

    public String getTabsBottom() {
        return tabsBottom;
    }

    public void setTabsBottom(String tabsBottom) {
        this.tabsBottom = tabsBottom;
    }


    public String getTabsBottomNoShare() {
        return tabsBottomNoShare;
    }

    public void setTabsBottomNoShare(String tabsBottomNoShare) {
        this.tabsBottomNoShare = tabsBottomNoShare;
    }

    public String getBrands() {
        return brands;
    }

    public void setBrands(String brands) {
        this.brands = brands;
    }


    public String getTabsTopAndroid() {
        return tabsTopAndroid;
    }

    public void setTabsTopAndroid(String tabsTopAndroid) {
        this.tabsTopAndroid = tabsTopAndroid;
    }

    public String getTabsBottomNoShareAndroid() {
        return tabsBottomNoShareAndroid;
    }

    public void setTabsBottomNoShareAndroid(String tabsBottomNoShareAndroid) {
        this.tabsBottomNoShareAndroid = tabsBottomNoShareAndroid;
    }

    public String getBrandsAndroid() {
        return brandsAndroid;
    }

    public void setBrandsAndroid(String brandsAndroid) {
        this.brandsAndroid = brandsAndroid;
    }

    public String getHeaderImage() {
        return headerImage;
    }

    public void setHeaderImage(String headerImage) {
        this.headerImage = headerImage;
    }

    public String getTabsBanner() {
        return tabsBanner;
    }

    public void setTabsBanner(String tabsBanner) {
        this.tabsBanner = tabsBanner;
    }
}
